@@ -2,4 +2,4 @@ from django.apps import AppConfig
 
 
 class DjangoSecurePasswordInput(AppConfig):
-    name = 'django_secure_password-input'
+    name = 'django_secure_password_input'
