@@ -1,4 +1,4 @@
-(function($){
+;!(function($){
     $(document).ready(function(){
         $(".django-secure-password-input").parents("form").submit(function(){
             var form = $(this);
